import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  scaleBand, 
  axisLeft, 
  axisBottom, 
  format 
} from 'd3';

const dataset = [80, 100, 56, 120, 180, 30, 40, 120, 160];
const svg = select('svg')

const width = +svg.attr('svgWidth')
const height= +svg.attr('svgHeight')

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 70, right: 20, bottom: 70, left: 130 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
    
  
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(.1);
  
  
  
  
  // console.log(yScale.domain())
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxisTickFormat = number => 
  	format('.3s')(number)
  		.replace('G', 'B')
  		.replace('0.00', '0');
  
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  
  g.append('g')
    .call(axisLeft(yScale))
  	.selectAll('.domain, .tick line')
  		.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  	
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 65)
  	.attr('x', innerWidth / 2)
  	.attr('fill', 'black')
  	.text('Population');
  
  
	g.selectAll('rect')
  	.data(data)
  	.enter()
  	.append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', yScale.bandwidth());
  
  g.append('text')
  	.attr('y', -10)
  	.attr('class', 'title')
		.text('Top 10 Most Populous Countries');
  
}








var svgWidth = 500, svgHeight = 300, barPadding = 5;
var barWidth = (svgWidth / dataset.length); //to calculate width of each bar
var svg = d3.select("svg")
    .attr('width', svgwidth)
    .attr('height', svgHeight);
var barchart = svg.selectAll("rect") // bars are nothing but rectangles
    .data(dataset) // waiting stare for our dataset
    .enter() // take element from the dataset to perform operation per each element
    .append("rect")
    .attr("y", function (d) { return svgHeight - d }) // calculate data to the spare parameter

    .attr("height", function (d) { return d; })

    .attr("width", barWidth - barPadding)
    .attr("transform", function (d, i) {   //operation to transform any object (element of the dataset), to transform for the rectangles
        var translate = [barWidth * i, 0]; //calculate the value of translation for our bars 2 values because of translation on x and y axes
        //multiple the index i by the bar width
        return "translate (" + translate + ")"; //to translate one after the other the objects
    });
